@@ -1,11 +1,10 @@
 #!/usr/bin/env bash
-# Convenience script for running Travis-like checks.
+# Convenience script for running CI-like checks
 
 set -eu
 set -x
 
-flake8 -j 2 .
-black --check .
+pre-commit run -a
 
 # Run tests, taking coverage.
 # Users can specify extra folders as arguments.
