@@ -2,11 +2,13 @@ import enum
 import os
 from datetime import datetime, timezone
 from pathlib import Path
-from typing import Iterable, Tuple
+from typing import Iterable, Tuple, Dict, Any
 
 import ciso8601
 import click
 
+EO3_SCHEMA = "https://schemas.opendatacube.org/dataset"
+
 
 class ItemProvider(enum.Enum):
     PRODUCER = "producer"
@@ -121,3 +123,30 @@ def get_collection_number(producer: str, usgs_collection_number: int) -> int:
     raise NotImplementedError(
         f"Unsupported collection number mapping for org: {producer!r}"
     )
+
+
+def is_doc_eo3(doc: Dict[str, Any]) -> bool:
+    """Is this document eo3?
+
+    :param doc: Parsed ODC Dataset metadata document
+
+    :returns:
+        False if this document is a legacy dataset
+        True if this document is eo3
+
+    :raises ValueError: For an unsupported document
+    """
+    schema = doc.get("$schema")
+    # All legacy documents had no schema at all.
+    if schema is None:
+        return False
+
+    if schema == EO3_SCHEMA:
+        return True
+
+    # Otherwise it has an unknown schema.
+    #
+    # Reject it for now.
+    # We don't want future documents (like Stac items, or "eo4") to be quietly
+    # accepted as legacy eo.
+    raise ValueError(f"Unsupported dataset schema: {schema!r}")
